src/hotspot/share/memory/filemap.hpp
changeset 51720 b7bfd64e43a6
parent 51491 187c84a5efe1
child 52514 f4e3900c8d08
--- a/src/hotspot/share/memory/filemap.hpp	Wed Sep 12 16:28:06 2018 -0700
+++ b/src/hotspot/share/memory/filemap.hpp	Wed Sep 12 17:45:22 2018 -0700
@@ -335,12 +335,12 @@
   }
 
   // The starting address of spc, as calculated with CompressedOop::decode_non_null()
-  address start_address_with_current_oop_encoding_mode(CDSFileMapRegion* spc) {
+  address start_address_as_decoded_with_current_oop_encoding_mode(CDSFileMapRegion* spc) {
     return decode_start_address(spc, true);
   }
 
-  // The starting address of spc, as calculated with HeapShared::decode_with_archived_oop_encoding_mode()
-  address start_address_with_archived_oop_encoding_mode(CDSFileMapRegion* spc) {
+  // The starting address of spc, as calculated with HeapShared::decode_from_archive()
+  address start_address_as_decoded_from_archive(CDSFileMapRegion* spc) {
     return decode_start_address(spc, false);
   }